==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/translateplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/translateplugin/translate.png
  0x0,0x0,0x1,0xdf,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x41,0x64,0x6f,0x62,0x65,0x20,0x49,0x6d,0x61,0x67,0x65,0x52,0x65,0x61,0x64,
  0x79,0x71,0xc9,0x65,0x3c,0x0,0x0,0x1,0x81,0x49,0x44,0x41,0x54,0x78,0xda,0x9c,
  0x53,0xc1,0x4a,0xc3,0x40,0x10,0x9d,0x4d,0x66,0x93,0x82,0xa6,0x2d,0xe6,0xae,0x82,
  0xdf,0xa1,0x22,0xf4,0x52,0xa4,0x1f,0xd0,0x83,0x7f,0xa6,0x16,0xbf,0x40,0x6d,0xa8,
  0xa0,0x15,0x44,0x3d,0xd8,0xcf,0x50,0xaf,0xd,0xd8,0x43,0x2f,0xd5,0xdd,0xac,0x3b,
  0x93,0x6c,0x62,0x68,0x41,0xed,0x83,0x25,0x93,0xb7,0x33,0x2f,0xb3,0x2f,0xb3,0x62,
  0x34,0x1a,0x7d,0x68,0xad,0xdb,0x59,0x96,0xc1,0x7f,0xe0,0x79,0x1e,0xf8,0xbe,0x3f,
  0x43,0x2a,0xee,0xf5,0x7a,0xb0,0xe,0x92,0x24,0x69,0xa3,0xfb,0xf2,0xeb,0xdb,0x3b,
  0xab,0xfe,0x5,0x54,0xb3,0xbb,0xb3,0xcd,0x4f,0x14,0x42,0x30,0x19,0x45,0x1b,0xb6,
  0x25,0x2c,0x44,0x8c,0xdd,0x34,0xfc,0x4,0x10,0x40,0x39,0x2e,0x8f,0x8a,0xb4,0x56,
  0x1c,0x13,0x87,0x4e,0xb5,0xdf,0x3f,0x81,0x30,0xc,0x0,0x51,0x72,0xa1,0x52,0xa,
  0x3a,0x9d,0xe,0x8c,0xc7,0xf7,0x56,0x54,0xd0,0x79,0x59,0x4c,0xa9,0x2f,0x58,0x2c,
  0x3e,0xe1,0xee,0xf6,0x26,0xf7,0xc2,0x9,0x6c,0x36,0x23,0x48,0x86,0x57,0x10,0xc7,
  0x5b,0x76,0xc5,0x1c,0xbf,0x4c,0x26,0x70,0xdc,0xed,0xc2,0xf0,0xfa,0x92,0x39,0xda,
  0x23,0x9e,0x72,0x1d,0xd0,0x18,0xc3,0xc1,0xc5,0x60,0x0,0x4a,0x67,0x10,0xb5,0x5a,
  0xfc,0x4e,0xf1,0xf9,0xd9,0x29,0xd0,0xbe,0xd2,0x1a,0xa2,0x66,0x8b,0x1a,0x60,0x9e,
  0x72,0x9,0xb4,0x87,0x95,0x31,0x74,0xae,0xc,0x1a,0x61,0xe8,0x18,0x6e,0x37,0x87,
  0x84,0x46,0xa3,0xe2,0xf3,0xdc,0xa2,0x83,0xea,0xbf,0x22,0x9b,0x98,0xa6,0x29,0xbf,
  0xe7,0x86,0xfa,0x65,0x5c,0xe7,0x71,0x59,0x20,0x8,0x90,0x3a,0x84,0x74,0x3a,0xcd,
  0x1d,0x66,0x4e,0x96,0x71,0x9d,0xaf,0x4,0x3c,0xe7,0x41,0x20,0x25,0xec,0x1f,0x1c,
  0x59,0x87,0x17,0xbc,0x28,0xe,0x24,0xf2,0x5a,0xe6,0xe5,0x2a,0xf,0xc,0x3c,0x3f,
  0x3d,0xd4,0x6,0x46,0xeb,0x5c,0x7c,0x99,0xcf,0xec,0x51,0xf2,0xb9,0x28,0x7,0x89,
  0xfe,0x35,0x29,0x8a,0x22,0x89,0x47,0x48,0x98,0xe2,0x4b,0x50,0xe3,0x29,0xb7,0x1c,
  0x24,0x37,0xbe,0x4e,0xc8,0x41,0xac,0xe0,0x1c,0xff,0xf3,0x42,0xe1,0x7c,0x3e,0x7f,
  0xb4,0x97,0xe2,0x90,0xef,0x44,0xe1,0xc7,0xaf,0xb0,0xc2,0x54,0x4c,0xb5,0x24,0xb8,
  0x67,0x57,0x1b,0xd6,0xc3,0xec,0x5b,0x80,0x1,0x0,0xe5,0x28,0xb0,0xd8,0x75,0x44,
  0x3f,0x3f,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // translate.png
  0x0,0xd,
  0xf,0xb8,0xe2,0xe7,
  0x0,0x74,
  0x0,0x72,0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x6c,0x0,0x61,0x0,0x74,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/translate.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/translateplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/translateplugin/translate.png
  0x0,0x0,0x1,0xdf,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x41,0x64,0x6f,0x62,0x65,0x20,0x49,0x6d,0x61,0x67,0x65,0x52,0x65,0x61,0x64,
  0x79,0x71,0xc9,0x65,0x3c,0x0,0x0,0x1,0x81,0x49,0x44,0x41,0x54,0x78,0xda,0x9c,
  0x53,0xc1,0x4a,0xc3,0x40,0x10,0x9d,0x4d,0x66,0x93,0x82,0xa6,0x2d,0xe6,0xae,0x82,
  0xdf,0xa1,0x22,0xf4,0x52,0xa4,0x1f,0xd0,0x83,0x7f,0xa6,0x16,0xbf,0x40,0x6d,0xa8,
  0xa0,0x15,0x44,0x3d,0xd8,0xcf,0x50,0xaf,0xd,0xd8,0x43,0x2f,0xd5,0xdd,0xac,0x3b,
  0x93,0x6c,0x62,0x68,0x41,0xed,0x83,0x25,0x93,0xb7,0x33,0x2f,0xb3,0x2f,0xb3,0x62,
  0x34,0x1a,0x7d,0x68,0xad,0xdb,0x59,0x96,0xc1,0x7f,0xe0,0x79,0x1e,0xf8,0xbe,0x3f,
  0x43,0x2a,0xee,0xf5,0x7a,0xb0,0xe,0x92,0x24,0x69,0xa3,0xfb,0xf2,0xeb,0xdb,0x3b,
  0xab,0xfe,0x5,0x54,0xb3,0xbb,0xb3,0xcd,0x4f,0x14,0x42,0x30,0x19,0x45,0x1b,0xb6,
  0x25,0x2c,0x44,0x8c,0xdd,0x34,0xfc,0x4,0x10,0x40,0x39,0x2e,0x8f,0x8a,0xb4,0x56,
  0x1c,0x13,0x87,0x4e,0xb5,0xdf,0x3f,0x81,0x30,0xc,0x0,0x51,0x72,0xa1,0x52,0xa,
  0x3a,0x9d,0xe,0x8c,0xc7,0xf7,0x56,0x54,0xd0,0x79,0x59,0x4c,0xa9,0x2f,0x58,0x2c,
  0x3e,0xe1,0xee,0xf6,0x26,0xf7,0xc2,0x9,0x6c,0x36,0x23,0x48,0x86,0x57,0x10,0xc7,
  0x5b,0x76,0xc5,0x1c,0xbf,0x4c,0x26,0x70,0xdc,0xed,0xc2,0xf0,0xfa,0x92,0x39,0xda,
  0x23,0x9e,0x72,0x1d,0xd0,0x18,0xc3,0xc1,0xc5,0x60,0x0,0x4a,0x67,0x10,0xb5,0x5a,
  0xfc,0x4e,0xf1,0xf9,0xd9,0x29,0xd0,0xbe,0xd2,0x1a,0xa2,0x66,0x8b,0x1a,0x60,0x9e,
  0x72,0x9,0xb4,0x87,0x95,0x31,0x74,0xae,0xc,0x1a,0x61,0xe8,0x18,0x6e,0x37,0x87,
  0x84,0x46,0xa3,0xe2,0xf3,0xdc,0xa2,0x83,0xea,0xbf,0x22,0x9b,0x98,0xa6,0x29,0xbf,
  0xe7,0x86,0xfa,0x65,0x5c,0xe7,0x71,0x59,0x20,0x8,0x90,0x3a,0x84,0x74,0x3a,0xcd,
  0x1d,0x66,0x4e,0x96,0x71,0x9d,0xaf,0x4,0x3c,0xe7,0x41,0x20,0x25,0xec,0x1f,0x1c,
  0x59,0x87,0x17,0xbc,0x28,0xe,0x24,0xf2,0x5a,0xe6,0xe5,0x2a,0xf,0xc,0x3c,0x3f,
  0x3d,0xd4,0x6,0x46,0xeb,0x5c,0x7c,0x99,0xcf,0xec,0x51,0xf2,0xb9,0x28,0x7,0x89,
  0xfe,0x35,0x29,0x8a,0x22,0x89,0x47,0x48,0x98,0xe2,0x4b,0x50,0xe3,0x29,0xb7,0x1c,
  0x24,0x37,0xbe,0x4e,0xc8,0x41,0xac,0xe0,0x1c,0xff,0xf3,0x42,0xe1,0x7c,0x3e,0x7f,
  0xb4,0x97,0xe2,0x90,0xef,0x44,0xe1,0xc7,0xaf,0xb0,0xc2,0x54,0x4c,0xb5,0x24,0xb8,
  0x67,0x57,0x1b,0xd6,0xc3,0xec,0x5b,0x80,0x1,0x0,0xe5,0x28,0xb0,0xd8,0x75,0x44,
  0x3f,0x3f,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // translate.png
  0x0,0xd,
  0xf,0xb8,0xe2,0xe7,
  0x0,0x74,
  0x0,0x72,0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x6c,0x0,0x61,0x0,0x74,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons/translate.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
